package com.bweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.enum_type.UserObjectTypeEnum;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.BsOrganizationService;
import com.hai.service.HighTyAgentOilStationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value = "/tyAgentOilStation")
@Api(value = "订单接口")
public class HighTyAgentOilStationController {

    private static Logger log = LoggerFactory.getLogger(HighTyAgentOilStationController.class);

    @Resource
    private HighTyAgentOilStationService highTyAgentOilStationService;

    @Resource
    private BsOrganizationService organizationService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value = "/assignOrg", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "分配机构")
    public ResponseData assignOrg(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            if (userModel.getBsCompany() == null || !userModel.getSecUser().getAdminFlag().equals(1)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            if (body.getLong("orgId") == null
                    || body.getJSONArray("storeList") == null
                    || body.getJSONArray("storeList").size() == 0
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> storeList = new ArrayList<>();
            for (Object obj : body.getJSONArray("storeList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("storeId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                storeList.add(objData.getLong("storeId"));
            }
            highTyAgentOilStationService.assignOrg(body.getLong("orgId"), storeList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/unbindOrg", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "解绑机构")
    public ResponseData unbindOrg(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            if (userModel.getBsCompany() == null || !userModel.getSecUser().getAdminFlag().equals(1)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            if (body.getJSONArray("oilStationList") == null
                    || body.getJSONArray("oilStationList").size() == 0) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> oilStationList = new ArrayList<>();
            for (Object obj : body.getJSONArray("oilStationList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("oilStationId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                oilStationList.add(objData.getLong("oilStationId"));
            }
            highTyAgentOilStationService.unbindOrg(oilStationList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/assignAgent", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "分配代理商")
    public ResponseData assignAgent(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }

            if (body.getLong("agentId") == null
                    || body.getJSONArray("oilStationList") == null
                    || body.getJSONArray("oilStationList").size() == 0
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> storeList = new ArrayList<>();
            for (Object obj : body.getJSONArray("oilStationList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("oilStationId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                storeList.add(objData.getLong("oilStationId"));
            }
            highTyAgentOilStationService.assignAgent(body.getLong("agentId"), storeList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/unbindAgent", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "解绑代理商")
    public ResponseData unbindAgent(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            if (userModel.getBsCompany() == null && !userModel.getSecUser().getAdminFlag().equals(1)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            if (body.getJSONArray("oilStationList") == null
                    || body.getJSONArray("oilStationList").size() == 0) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> oilStationList = new ArrayList<>();
            for (Object obj : body.getJSONArray("oilStationList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("oilStationId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                oilStationList.add(objData.getLong("oilStationId"));
            }
            highTyAgentOilStationService.unbindAgent(oilStationList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/assignSalesman", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "分配业务员")
    public ResponseData assignSalesman(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            if (!userModel.getSecUser().getObjectType().equals(UserObjectTypeEnum.type6.getType())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            if (body.getLong("salesmanId") == null
                    || body.getJSONArray("oilStationList") == null
                    || body.getJSONArray("oilStationList").size() == 0
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> storeList = new ArrayList<>();
            for (Object obj : body.getJSONArray("oilStationList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("oilStationId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                storeList.add(objData.getLong("oilStationId"));
            }
            highTyAgentOilStationService.assignSalesman(body.getLong("salesmanId"), storeList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/unbindSalesman", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "解绑业务员")
    public ResponseData unbindSalesman(@RequestBody JSONObject body) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            if (userModel.getBsCompany() != null && !userModel.getSecUser().getAdminFlag().equals(1)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            if (body.getJSONArray("oilStationList") == null
                    || body.getJSONArray("oilStationList").size() == 0) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            List<Long> oilStationList = new ArrayList<>();
            for (Object obj : body.getJSONArray("oilStationList")) {
                JSONObject objData = (JSONObject)obj;
                if (objData.getLong("oilStationId") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                oilStationList.add(objData.getLong("oilStationId"));
            }
            highTyAgentOilStationService.unbindSalesman(oilStationList);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentController --> assignOrg() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOilStationList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询加油站列表")
    public ResponseData getOilStationList(@RequestParam(name = "regionName", required = false) String regionName,
                                          @RequestParam(name = "storeName", required = false) String storeName,
                                          @RequestParam(name = "isAssignOrgId", required = false) Boolean isAssignOrgId,
                                          @RequestParam(name = "organizationName", required = false) String organizationName,
                                          @RequestParam(name = "isAssignTyAgent", required = false) Boolean isAssignTyAgent,
                                          @RequestParam(name = "tyAgentName", required = false) String tyAgentName,
                                          @RequestParam(name = "isAssignTySalesman", required = false) Boolean isAssignTySalesman,
                                          @RequestParam(name = "tySalesmanName", required = false) String tySalesmanName,
                                          @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                          @RequestParam(name = "pageSize", required = true) Integer pageSize) {
        try {
            UserInfoModel userModel = userCenter.getSessionModel(UserInfoModel.class);
            if (userModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            Map<String, Object> param = new HashMap<>();
            param.put("regionName", regionName);
            param.put("storeName", storeName);

            if (userModel.getBsCompany() != null && userModel.getSecUser().getAdminFlag().equals(1)) {
                param.put("isAssignOrgId", isAssignOrgId);
                param.put("organizationName", organizationName);
                param.put("isAssignTyAgent", isAssignTyAgent);
                param.put("tyAgentName", tyAgentName);
                param.put("isAssignTySalesman", isAssignTySalesman);
                param.put("tySalesmanName", tySalesmanName);

            } else if (userModel.getBsCompany() != null && userModel.getSecUser().getAdminFlag().equals(0)) {
                param.put("organizationId", userModel.getBsOrganization().getId());
                param.put("isAssignTyAgent", isAssignTyAgent);
                param.put("tyAgentName", tyAgentName);
                param.put("isAssignTySalesman", isAssignTySalesman);
                param.put("tySalesmanName", tySalesmanName);

            } else if (userModel.getSecUser().getObjectType().equals(UserObjectTypeEnum.type6.getType())) {
                param.put("tyAgentId", userModel.getHighTyAgent().getId());
                param.put("isAssignTySalesman", isAssignTySalesman);
                param.put("tySalesmanName", tySalesmanName);

            } else if (userModel.getSecUser().getObjectType().equals(UserObjectTypeEnum.type7.getType())) {
                param.put("tySalesmanId", userModel.getHighTySalesman().getId());
            }

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highTyAgentOilStationService.getOilStationList(param)));

        } catch (Exception e) {
            log.error("HighTyAgentController --> getOilStationList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
