package com.bweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighGasOilPrice;
import com.hai.entity.HighMerchantStore;
import com.hai.entity.HighTyAgentPrice;
import com.hai.model.ResponseData;
import com.hai.service.HighGasOilPriceService;
import com.hai.service.HighMerchantStoreService;
import com.hai.service.HighTyAgentPriceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value = "/tyAgentPrice")
@Api(value = "订单接口")
public class HighTyAgentPriceController {

    private static Logger log = LoggerFactory.getLogger(HighTyAgentPriceController.class);

    @Resource
    private HighTyAgentPriceService tyAgentPriceService;

    @Resource
    private HighMerchantStoreService merchantStoreService;

    @Resource
    private HighGasOilPriceService gasOilPriceService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value = "/editPrice", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "编辑价格")
    public ResponseData editPrice(@RequestBody JSONObject body) {
        try {

            if (body.getLong("tyAgentOilStationId") == null
                || StringUtils.isBlank(body.getString("oilNoName"))
                || StringUtils.isBlank(body.getString("oilNo"))
                || body.getBigDecimal("priceRate") == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            // 查询油站
            HighTyAgentPrice agentOilStation = tyAgentPriceService.getDetail(body.getLong("tyAgentOilStationId"), body.getString("oilNo"));
            if (agentOilStation == null) {
                agentOilStation = new HighTyAgentPrice();
                agentOilStation.setTyAgentOilStationId(body.getLong("tyAgentOilStationId"));
                agentOilStation.setOilNoName(body.getString("oilNoName"));
                agentOilStation.setOilNo(body.getString("oilNo"));
                agentOilStation.setPriceRate(body.getBigDecimal("priceRate"));
            } else {
                agentOilStation.setPriceRate(body.getBigDecimal("priceRate"));
            }

            tyAgentPriceService.editTyAgentPrice(agentOilStation);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentPriceController --> editPrice() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOilStationPrice", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "油站价格")
    public ResponseData getOilStationPrice(@RequestParam(name = "oilStationId", required = true) Long oilStationId) {
        try {

            List<HighGasOilPrice> oilPriceList = gasOilPriceService.getGasOilPriceByStore(oilStationId);

            List<Map<String, Object>> oilPriceMapList = new ArrayList<>();
            Map<String, Object> oilPriceMap;

            for (HighGasOilPrice price : oilPriceList) {
                oilPriceMap = new HashMap<>();
                oilPriceMap.put("oilStationId", oilStationId);
                oilPriceMap.put("oilNo", price.getOilNo());
                oilPriceMap.put("oilNoName", price.getOilNoName());

                oilPriceMapList.add(oilPriceMap);
                HighTyAgentPrice tyAgentPrice = tyAgentPriceService.getDetail(oilStationId, price.getOilNo().toString());
            }

            return ResponseMsgUtil.success(oilPriceList);

        } catch (Exception e) {
            log.error("HighTyAgentPriceController --> getOilStationPrice() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
